<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Tidak satupun',
    'Edit' => 'Edit',
    'Remove' => 'Hapus',
    'Yes' => 'Ya',
    'No' => 'Tidak',
    'cancel' => 'batal',
    'or' => 'atau',
    'Yellow' => 'Kuning',
    'Blue' => 'Biru',
    'Green' => 'Hijau',
    'Purple' => 'Ungu',
    'Red' => 'Merah',
    'Orange' => 'Jingga',
    'Grey' => 'Abu-abu',
    'Brown' => 'Coklat',
    'Deep Orange' => 'Oranye',
    'Dark Grey' => 'Abu-abu Gelap',
    'Pink' => 'Merah Muda',
    'Teal' => 'Teal',
    'Cyan' => 'Sian',
    'Lime' => 'Lime',
    'Light Green' => 'Hijau Muda',
    'Amber' => 'Amber',
    'Save' => 'Simpan',
    'Login' => 'Masuk',
    'Official website:' => 'Situs resmi:',
    'Unassigned' => 'Belum ditugaskan',
    'View this task' => 'Lihat tugas ini',
    'Remove user' => 'Hapus pengguna',
    'Do you really want to remove this user: "%s"?' => 'Anda yakin mau menghapus pengguna ini: "%s"?',
    'All users' => 'Semua pengguna',
    'Username' => 'Nama pengguna',
    'Password' => 'Kata sandi',
    'Administrator' => 'Administrator',
    'Sign in' => 'Masuk',
    'Users' => 'Pengguna',
    'Forbidden' => 'Terlarang',
    'Access Forbidden' => 'Akses Dilarang',
    'Edit user' => 'Edit pengguna',
    'Logout' => 'Keluar',
    'Bad username or password' => 'Nama pengguna atau password salah',
    'Edit project' => 'Edit proyek',
    'Name' => 'Nama',
    'Projects' => 'Proyek',
    'No project' => 'Tidak ada proyek',
    'Project' => 'Proyek',
    'Status' => 'Status',
    'Tasks' => 'Tugas',
    'Board' => 'Papan',
    'Actions' => 'Tindakan',
    'Inactive' => 'Non Aktif',
    'Active' => 'Aktif',
    'Unable to update this board.' => 'Tidak dapat memperbarui papan ini',
    'Disable' => 'Nonaktifkan',
    'Enable' => 'Aktifkan',
    'New project' => 'Proyek baru',
    'Do you really want to remove this project: "%s"?' => 'Apakah Anda yakin mau menghapus proyek ini: "%s"?',
    'Remove project' => 'Hapus proyek',
    'Edit the board for "%s"' => 'Edit papan untuk "%s"',
    'Add a new column' => 'Tambah kolom baru',
    'Title' => 'Judul',
    'Assigned to %s' => 'Ditugaskan kepada %s',
    'Remove a column' => 'Hapus kolom',
    'Unable to remove this column.' => 'Tidak dapat menghapus kolom ini.',
    'Do you really want to remove this column: "%s"?' => 'Apakah Anda yakin mau menghapus kolom ini: "%s"?',
    'Settings' => 'Pengaturan',
    'Application settings' => 'Pengaturan aplikasi',
    'Language' => 'Bahasa',
    'Webhook token:' => 'Token Webhook:',
    'API token:' => 'Token API:',
    'Database size:' => 'Ukuran database:',
    'Download the database' => 'Unduh database',
    'Optimize the database' => 'Optimasi database',
    '(VACUUM command)' => '(Perintah VACUUM)',
    '(Gzip compressed Sqlite file)' => '(File Sqlite yang terkompress Gzip)',
    'Close a task' => 'Tutup tugas',
    'Column' => 'Kolom',
    'Color' => 'Warna',
    'Assignee' => 'Orang yang ditugaskan',
    'Create another task' => 'Buat tugas lain',
    'New task' => 'Tugas baru',
    'Open a task' => 'Buka tugas',
    'Do you really want to open this task: "%s"?' => 'Apakah Anda yakin mau membuka tugas ini: "%s"?',
    'Back to the board' => 'Kembali ke papan',
    'There is nobody assigned' => 'Tidak ada orang yand ditugaskan',
    'Column on the board:' => 'Kolom di dalam papan:',
    'Close this task' => 'Tutup tugas ini',
    'Open this task' => 'Buka tugas ini',
    'There is no description.' => 'Tidak ada deskripsi.',
    'Add a new task' => 'Tambah tugas baru',
    'The username is required' => 'Nama pengguna dibutuhkan',
    'The maximum length is %d characters' => 'Panjang maksimum adalah %d karakter',
    'The minimum length is %d characters' => 'Panjang minimum adalah %d karakter',
    'The password is required' => 'Password dibutuhkan',
    'This value must be an integer' => 'Nilai ini harus integer',
    'The username must be unique' => 'Nama pengguna harus unik',
    'The user id is required' => 'ID pengguna diperlukan',
    'Passwords don\'t match' => 'Password tidak cocok',
    'The confirmation is required' => 'Konfirmasi diperlukan',
    'The project is required' => 'Proyek diperlukan',
    'The id is required' => 'ID diperlukan',
    'The project id is required' => 'ID proyek diperlukan',
    'The project name is required' => 'Nama proyek diperlukan',
    'The title is required' => 'Judul diperlukan',
    'Settings saved successfully.' => 'Pengaturan berhasil disimpan.',
    'Unable to save your settings.' => 'Tidak dapat menyimpan pengaturan anda.',
    'Database optimization done.' => 'Optimasi database selesai.',
    'Your project has been created successfully.' => 'Proyek anda berhasil dibuat.',
    'Unable to create your project.' => 'Tidak dapat membuat proyek anda.',
    'Project updated successfully.' => 'Proyek berhasil diperbarui.',
    'Unable to update this project.' => 'Tidak dapat memperbarui proyek ini.',
    'Unable to remove this project.' => 'Tidak dapat menghapus proyek ini.',
    'Project removed successfully.' => 'Proyek berhasil dihapus.',
    'Project activated successfully.' => 'Proyek berhasil diaktifkan.',
    'Unable to activate this project.' => 'Tidak dapat mengaktifkan proyek ini.',
    'Project disabled successfully.' => 'Proyek berhasil dinonaktifkan.',
    'Unable to disable this project.' => 'Tidak dapat menonaktifkan proyek ini.',
    'Unable to open this task.' => 'Tidak dapat membuka tugas ini.',
    'Task opened successfully.' => 'Tugas berhasil dibuka.',
    'Unable to close this task.' => 'Tidak dapat menutup tugas ini.',
    'Task closed successfully.' => 'Tugas berhasil ditutup.',
    'Unable to update your task.' => 'Tidak dapat memperbarui tugas ini.',
    'Task updated successfully.' => 'Tugas berhasil diperbarui.',
    'Unable to create your task.' => 'Tidak dapat membuat tugas anda.',
    'Task created successfully.' => 'Tugas berhasil dibuat.',
    'User created successfully.' => 'Pengguna berhasil dibuat.',
    'Unable to create your user.' => 'Tidak dapat membuat pengguna Anda.',
    'User updated successfully.' => 'Pengguna berhasil diperbarui.',
    'User removed successfully.' => 'Pengguna berhasil dihapus.',
    'Unable to remove this user.' => 'Tidak dapat menghapus pengguna ini.',
    'Board updated successfully.' => 'Papan berhasil diperbaharui.',
    'Ready' => 'Siap',
    'Backlog' => 'Tertunda',
    'Work in progress' => 'Sedang dalam pengerjaan',
    'Done' => 'Selesai',
    'Application version:' => 'Versi aplikasi:',
    'Id' => 'ID',
    'Public link' => 'Tautan publik',
    'Timezone' => 'Zona waktu',
    'Sorry, I didn\'t find this information in my database!' => 'Maaf, saya tidak dapat menemukan informasi ini dalam database saya!',
    'Page not found' => 'Halaman tidak ditemukan',
    'Complexity' => 'Kompleksitas',
    'Task limit' => 'Batas tugas',
    'Task count' => 'Jumlah tugas',
    'User' => 'Pengguna',
    'Comments' => 'Komentar',
    'Comment is required' => 'Komentar dibutuhkan',
    'Comment added successfully.' => 'Komentar berhasil ditambahkan.',
    'Unable to create your comment.' => 'Tidak dapat menambahkan komentar Anda.',
    'Due Date' => 'Batas Tanggal Terakhir',
    'Invalid date' => 'Tanggal tidak sesuai',
    'Automatic actions' => 'Tindakan otomatis',
    'Your automatic action has been created successfully.' => 'Tindakan otomatis Anda berhasil dibuat.',
    'Unable to create your automatic action.' => 'Tidak dapat membuat tindakan otomatis Anda.',
    'Remove an action' => 'Hapus tindakan',
    'Unable to remove this action.' => 'Tidak dapat menghapus tindakan ini.',
    'Action removed successfully.' => 'Tindakan berhasil dihapus.',
    'Automatic actions for the project "%s"' => 'Tindakan otomatis untuk proyek ini "%s"',
    'Add an action' => 'Tambah tindakan',
    'Event name' => 'Nama acara',
    'Action' => 'Tindakan',
    'Event' => 'Acara',
    'When the selected event occurs execute the corresponding action.' => 'Ketika acara yang dipilih terjadi, tindakan yang berhubungan dengan acara akan dieksekusi.',
    'Next step' => 'Langkah selanjutnya',
    'Define action parameters' => 'Definisi parameter tindakan',
    'Do you really want to remove this action: "%s"?' => 'Apakah Anda yakin mau menghapus tindakan ini: "%s"?',
    'Remove an automatic action' => 'Hapus tindakan otomatis',
    'Assign the task to a specific user' => 'Berikan tugas pada pengguna tertentu',
    'Assign the task to the person who does the action' => 'Berikan tugas pada orang yang melakukan tindakan',
    'Duplicate the task to another project' => 'Duplikasi tugas ke proyek lain',
    'Move a task to another column' => 'Pindahkan tugas ke kolom lain',
    'Task modification' => 'Modifikasi tugas',
    'Task creation' => 'Membuat tugas',
    'Closing a task' => 'Menutup tugas',
    'Assign a color to a specific user' => 'Menetapkan warna untuk pengguna tertentu',
    'Position' => 'Posisi',
    'Duplicate to project' => 'Duplikasi ke proyek lain',
    'Duplicate' => 'Duplikat',
    'Link' => 'tautan',
    'Comment updated successfully.' => 'Komentar berhasil diperbarui.',
    'Unable to update your comment.' => 'Tidak dapat memperbarui komentar Anda.',
    'Remove a comment' => 'Hapus komentar',
    'Comment removed successfully.' => 'Komentar berhasil dihapus.',
    'Unable to remove this comment.' => 'Tidak dapat menghapus komentar ini.',
    'Do you really want to remove this comment?' => 'Apakah Anda yakin mau menghapus komentar ini?',
    'Current password for the user "%s"' => 'Password saat ini untuk pengguna "%s"',
    'The current password is required' => 'Password saat ini diperlukan',
    'Wrong password' => 'Password salah',
    'Unknown' => 'Tidak diketahui',
    'Last logins' => 'Masuk terakhir',
    'Login date' => 'Tanggal masuk',
    'Authentication method' => 'Metode otentifikasi',
    'IP address' => 'Alamat IP',
    'User agent' => 'Agen pengguna',
    'Persistent connections' => 'Koneksi tetap',
    'No session.' => 'Tidak ada sesi.',
    'Expiration date' => 'Tanggal kadaluarsa',
    'Remember Me' => 'Ingat Saya',
    'Creation date' => 'Tanggal pembuatan',
    'Everybody' => 'Semua orang',
    'Open' => 'Terbuka',
    'Closed' => 'Ditutup',
    'Search' => 'Cari',
    'Nothing found.' => 'Tidak ditemukan.',
    'Due date' => 'Batas tanggal terakhir',
    'Description' => 'Deskripsi',
    '%d comments' => '%d komentar',
    '%d comment' => '%d komentar',
    'Email address invalid' => 'Alamat email tidak sesuai',
    'Your external account is not linked anymore to your profile.' => 'Akun eksternal Anda tidak lagi terhubung ke profil anda.',
    'Unable to unlink your external account.' => 'Tidak dapat memutuskan akun eksternal Anda.',
    'External authentication failed' => 'Otentifikasi eksternal gagal',
    'Your external account is linked to your profile successfully.' => 'Akun eksternal Anda berhasil dihubungkan ke profil anda.',
    'Email' => 'Email',
    'Task removed successfully.' => 'Tugas berhasil dihapus.',
    'Unable to remove this task.' => 'Tidak dapat menghapus tugas ini.',
    'Remove a task' => 'Hapus tugas',
    'Do you really want to remove this task: "%s"?' => 'Apakah Anda yakin mau menghapus tugas ini: "%s"?',
    'Assign automatically a color based on a category' => 'Otomatis menetapkan warna berdasarkan kategori',
    'Assign automatically a category based on a color' => 'Otomatis menetapkan kategori berdasarkan warna',
    'Task creation or modification' => 'Tugas dibuat atau di modifikasi',
    'Category' => 'Kategori',
    'Category:' => 'Kategori:',
    'Categories' => 'Kategori',
    'Your category has been created successfully.' => 'Kategori Anda berhasil dibuat.',
    'This category has been updated successfully.' => 'Kategori Anda berhasil diperbarui.',
    'Unable to update this category.' => 'Tidak dapat memperbarui kategori Anda.',
    'Remove a category' => 'Hapus kategori',
    'Category removed successfully.' => 'Kategori berhasil dihapus.',
    'Unable to remove this category.' => 'Tidak dapat menghapus kategori ini.',
    'Category modification for the project "%s"' => 'Modifikasi kategori untuk proyek "%s"',
    'Category Name' => 'Nama Kategori',
    'Add a new category' => 'Tambah kategori baru',
    'Do you really want to remove this category: "%s"?' => 'Apakah Anda yakin mau menghapus kategori ini: "%s"?',
    'All categories' => 'Semua kategori',
    'No category' => 'Tidak ada kategori',
    'The name is required' => 'Nama diperlukan',
    'Remove a file' => 'Hapus berkas',
    'Unable to remove this file.' => 'Tidak dapat menghapus berkas ini.',
    'File removed successfully.' => 'Berkas berhasil dihapus.',
    'Attach a document' => 'Lampirkan dokumen',
    'Do you really want to remove this file: "%s"?' => 'Apakah Anda yakin akan menghapus berkas ini: "%s"?',
    'Attachments' => 'Lampiran',
    'Edit the task' => 'Edit tugas',
    'Add a comment' => 'Tambahkan komentar',
    'Edit a comment' => 'Edit komentar',
    'Summary' => 'Ringkasan',
    'Time tracking' => 'Pelacakan waktu',
    'Estimate:' => 'Estimasi:',
    'Spent:' => 'Menghabiskan:',
    'Do you really want to remove this sub-task?' => 'Apakah Anda yakin mau menghapus sub-tugas ini?',
    'Remaining:' => 'Tersisa:',
    'hours' => 'jam',
    'estimated' => 'perkiraan',
    'Sub-Tasks' => 'Sub-tugas',
    'Add a sub-task' => 'Tambahkan sub-tugas',
    'Original estimate' => 'Perkiraan semula',
    'Create another sub-task' => 'Tambahkan sub-tugas lainnya',
    'Time spent' => 'Waktu yang dihabiskan',
    'Edit a sub-task' => 'Edit sub-tugas',
    'Remove a sub-task' => 'Hapus sub-tugas',
    'The time must be a numeric value' => 'Waktu harus berupa angka',
    'Todo' => 'Yang harus dilakukan',
    'In progress' => 'Dalam proses',
    'Sub-task removed successfully.' => 'Sub-tugas berhasil dihapus.',
    'Unable to remove this sub-task.' => 'Tidak dapat menghapus sub-tugas.',
    'Sub-task updated successfully.' => 'Sub-tugas berhasil diperbarui.',
    'Unable to update your sub-task.' => 'Tidak dapat memperbarui sub-tugas Anda.',
    'Unable to create your sub-task.' => 'Tidak dapat membuat sub-tugas Anda.',
    'Maximum size: ' => 'Ukuran maksimum: ',
    'Display another project' => 'Lihat proyek lain',
    'Created by %s' => 'Dibuat oleh %s',
    'Tasks Export' => 'Ekspor Tugas',
    'Start Date' => 'Tanggal Mulai',
    'Execute' => 'Eksekusi',
    'Task Id' => 'ID Tugas',
    'Creator' => 'Pembuat',
    'Modification date' => 'Tanggal modifikasi',
    'Completion date' => 'Tanggal penyelesaian',
    'Clone' => 'Klon',
    'Project cloned successfully.' => 'Kloning proyek berhasil.',
    'Unable to clone this project.' => 'Tidak dapat mengkloning proyek.',
    'Enable email notifications' => 'Aktifkan pemberitahuan dari email',
    'Task position:' => 'Posisi tugas:',
    'The task #%d has been opened.' => 'Tugas #%d telah dibuka.',
    'The task #%d has been closed.' => 'Tugas #%d telah ditutup.',
    'Sub-task updated' => 'Sub-tugas diperbarui',
    'Title:' => 'Judul:',
    'Status:' => 'Status:',
    'Assignee:' => 'Ditugaskan ke:',
    'Time tracking:' => 'Pelacakan waktu:',
    'New sub-task' => 'Sub-tugas baru',
    'New attachment added "%s"' => 'Lampiran baru ditambahkan "%s"',
    'New comment posted by %s' => 'Komentar baru ditambahkan oleh %s',
    'New comment' => 'Komentar baru',
    'Comment updated' => 'Komentar diperbarui',
    'New subtask' => 'Sub-tugas baru',
    'I only want to receive notifications for these projects:' => 'Saya ingin menerima pemberitahuan hanya untuk proyek-proyek yang dipilih :',
    'view the task on Kanboard' => 'lihat tugas di Kanboard',
    'Public access' => 'Akses publik',
    'Disable public access' => 'Nonaktifkan akses publik',
    'Enable public access' => 'Aktifkan akses publik',
    'Public access disabled' => 'Akses publik dinonaktifkan',
    'Move the task to another project' => 'Pindahkan tugas ke proyek lain',
    'Move to project' => 'Pindahkan ke proyek lain',
    'Do you really want to duplicate this task?' => 'Apakah Anda yakin mau menduplikasi tugas ini?',
    'Duplicate a task' => 'Duplikasi tugas',
    'External accounts' => 'Akun eksternal',
    'Account type' => 'Tipe akun',
    'Local' => 'Lokal',
    'Remote' => 'Jarak Jauh',
    'Enabled' => 'Aktif',
    'Disabled' => 'Nonaktif',
    'Login:' => 'Masuk:',
    'Full Name:' => 'Nama Lengkap:',
    'Email:' => 'Email:',
    'Notifications:' => 'Pemberitahuan:',
    'Notifications' => 'Pemberitahuan',
    'Account type:' => 'Tipe akun:',
    'Edit profile' => 'Edit profil',
    'Change password' => 'Ganti password',
    'Password modification' => 'Modifikasi password',
    'External authentications' => 'Otentifikasi eksternal',
    'Never connected.' => 'Tidak pernah terhubung.',
    'No external authentication enabled.' => 'Tidak ada otentifikasi eksternal yang aktif.',
    'Password modified successfully.' => 'Password berhasil dimodifikasi.',
    'Unable to change the password.' => 'Tidak dapat mengganti kata sandi.',
    'Change category' => 'Ganti kategori',
    '%s updated the task %s' => '%s memperbarui tugas %s',
    '%s opened the task %s' => '%s membuka tugas %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s memindahkan tugas %s ke posisi #%d dalam kolom "%s"',
    '%s moved the task %s to the column "%s"' => '%s memindahkan tugas %s ke kolom "%s"',
    '%s created the task %s' => '%s membuat tugas %s',
    '%s closed the task %s' => '%s menutup tugas %s',
    '%s created a subtask for the task %s' => '%s membuat sub-tugas untuk tugas %s',
    '%s updated a subtask for the task %s' => '%s memperbarui sub-tugas untuk tugas %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Ditugaskan pada %s dengan perkiraan %s/%sh',
    'Not assigned, estimate of %sh' => 'Tidak ada yang ditugaskan, perkiraan %sh',
    '%s updated a comment on the task %s' => '%s memperbarui komentar pada tugas %s',
    '%s commented the task %s' => '%s memberikan komentar pada tugas %s',
    '%s\'s activity' => 'Aktifitas dari %s',
    'RSS feed' => 'Umpan RSS',
    '%s updated a comment on the task #%d' => '%s memperbarui komentar pada tugas #%d',
    '%s commented on the task #%d' => '%s memberikan komentar pada tugas #%d',
    '%s updated a subtask for the task #%d' => '%s memperbarui sub-tugas untuk tugas #%d',
    '%s created a subtask for the task #%d' => '%s membuat sub-tugas untuk tugas #%d',
    '%s updated the task #%d' => '%s memperbarui tugas #%d',
    '%s created the task #%d' => '%s membuat tugas #%d',
    '%s closed the task #%d' => '%s menutup tugas #%d',
    '%s opened the task #%d' => '%s membuka tugas #%d',
    'Activity' => 'Aktifitas',
    'Default values are "%s"' => 'Nilai default adalah "%s"',
    'Default columns for new projects (Comma-separated)' => 'Kolom default untuk proyek baru (dipisahkan dengan koma)',
    'Task assignee change' => 'Ganti orang yang ditugaskan',
    '%s changed the assignee of the task #%d to %s' => '%s mengganti orang yang ditugaskan dari tugas #%d ke %s',
    '%s changed the assignee of the task %s to %s' => '%s mengganti orang yang ditugaskan dari tugas %s ke %s',
    'New password for the user "%s"' => 'Password baru untuk pengguna "%s"',
    'Choose an event' => 'Pilih acara',
    'Create a task from an external provider' => 'Buat tugas dari penyedia eksternal',
    'Change the assignee based on an external username' => 'Ganti penugasan berdasarkan nama pengguna eksternal',
    'Change the category based on an external label' => 'Ganti kategori berdasarkan label eksternal',
    'Reference' => 'Referensi',
    'Label' => 'Label',
    'Database' => 'Database',
    'About' => 'Tentang',
    'Database driver:' => 'Driver database:',
    'Board settings' => 'Pengaturan papan',
    'Webhook settings' => 'Pengaturan Webhook',
    'Reset token' => 'Reset token',
    'API endpoint:' => 'API endpoint :',
    'Refresh interval for personal board' => 'Interval pembaruan untuk papan pribadi',
    'Refresh interval for public board' => 'Interval pembaruan untuk papan publik',
    'Task highlight period' => 'Periode penyorotan tugas',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periode (dalam detik) untuk mempertimbangkan tugas yang baru dimodifikasi (0 untuk menonaktifkan, default 2 hari)',
    'Frequency in second (60 seconds by default)' => 'Frekuensi dalam detik (default 60 detik)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekuensi dalam detik (0 untuk menonaktifkan fitur ini, default 10 detik)',
    'Application URL' => 'URL Aplikasi',
    'Token regenerated.' => 'Token diregenerasi.',
    'Date format' => 'Format tanggal',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Format ISO selalu diterima, contoh: "%s" dan "%s"',
    'New personal project' => 'Proyek pribadi baru',
    'This project is personal' => 'Proyek ini pribadi',
    'Add' => 'Tambah',
    'Start date' => 'Tanggal mulai',
    'Time estimated' => 'Perkiraan waktu',
    'There is nothing assigned to you.' => 'Tidak ada tugas yang diberikan pada Anda.',
    'My tasks' => 'Tugas saya',
    'Activity stream' => 'Arus aktifitas',
    'Dashboard' => 'Dasbor',
    'Confirmation' => 'Konfirmasi',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Buat komentar dari penyedia eksternal',
    'Project management' => 'Manajemen proyek',
    'Columns' => 'Kolom',
    'Task' => 'Tugas',
    'Percentage' => 'Persentasi',
    'Number of tasks' => 'Jumlah dari tugas',
    'Task distribution' => 'Pembagian tugas',
    'Analytics' => 'Analitik',
    'Subtask' => 'Sub-tugas',
    'User repartition' => 'Partisi ulang pengguna',
    'Clone this project' => 'Klon proyek ini',
    'Column removed successfully.' => 'Kolom berhasil dihapus.',
    'Not enough data to show the graph.' => 'Tidak cukup data untuk menampilkan grafik.',
    'Previous' => 'Sebelumnya',
    'The id must be an integer' => 'ID harus integer',
    'The project id must be an integer' => 'ID proyek harus integer',
    'The status must be an integer' => 'Status harus integer',
    'The subtask id is required' => 'ID sub-tugas diperlukan',
    'The subtask id must be an integer' => 'ID sub-tugas harus integer',
    'The task id is required' => 'ID tugas diperlukan',
    'The task id must be an integer' => 'ID tugas harus integer',
    'The user id must be an integer' => 'ID user harus integer',
    'This value is required' => 'Nilai ini diperlukan',
    'This value must be numeric' => 'Nilai ini harus angka',
    'Unable to create this task.' => 'Tidak dapat membuat tugas ini',
    'Cumulative flow diagram' => 'Diagram alir kumulatif',
    'Daily project summary' => 'Ringkasan proyek harian',
    'Daily project summary export' => 'Ekspor ringkasan proyek harian',
    'Exports' => 'Ekspor',
    'This export contains the number of tasks per column grouped per day.' => 'Ekspor ini berisi jumlah dari tugas per kolom yang dikelompokan per hari.',
    'Active swimlanes' => 'Swimlanes aktif',
    'Add a new swimlane' => 'Tambah swimlane baru',
    'Default swimlane' => 'Swimlane default',
    'Do you really want to remove this swimlane: "%s"?' => 'Apakah Anda yakin mau menghapus swimlane ini: "%s"?',
    'Inactive swimlanes' => 'Swimlanes tidak aktif',
    'Remove a swimlane' => 'Hapus swimlane',
    'Swimlane modification for the project "%s"' => 'Modifikasi swimlane untuk proyek "%s"',
    'Swimlane removed successfully.' => 'Swimlane berhasil dihapus.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane berhasil diperbarui.',
    'Unable to remove this swimlane.' => 'Tidak dapat menghapus swimlane ini.',
    'Unable to update this swimlane.' => 'Tidak dapat memperbarui swimlane ini.',
    'Your swimlane has been created successfully.' => 'Swimlane Anda berhasil dibuat.',
    'Example: "Bug, Feature Request, Improvement"' => 'Contoh: "Bug, Permintaan Fitur, Peningkatan"',
    'Default categories for new projects (Comma-separated)' => 'Kategori default untuk proyek baru (dipisahkan dengan koma)',
    'Integrations' => 'Integrasi',
    'Integration with third-party services' => 'Integrasi dengan layanan pihak ketiga',
    'Subtask Id' => 'ID Sub-tugas',
    'Subtasks' => 'Sub-tugas',
    'Subtasks Export' => 'Ekspor Sub-tugas',
    'Task Title' => 'Judul Tugas',
    'Untitled' => 'Tanpa Nama',
    'Application default' => 'Default aplikasi',
    'Language:' => 'Bahasa:',
    'Timezone:' => 'Zona waktu:',
    'All columns' => 'Semua kolom',
    'Next' => 'Selanjutnya',
    '#%d' => '#%d',
    'All swimlanes' => 'Semua swimlane',
    'All colors' => 'Semua warna',
    'Moved to column %s' => 'Pindah ke kolom %s',
    'User dashboard' => 'Dasbor pengguna',
    'Allow only one subtask in progress at the same time for a user' => 'Izinkan hanya satu sub-tugas dalam proses secara bersamaan untuk satu pengguna',
    'Edit column "%s"' => 'Edit kolom "%s"',
    'Select the new status of the subtask: "%s"' => 'Pilih status baru untuk sub-tugas: "%s"',
    'Subtask timesheet' => 'Absen sub-tugas',
    'There is nothing to show.' => 'Tidak ada yang bisa diperlihatkan.',
    'Time Tracking' => 'Pelacakan Waktu',
    'You already have one subtask in progress' => 'Anda sudah memiliki satu sub-tugas dalam proses',
    'Which parts of the project do you want to duplicate?' => 'Bagian proyek mana yang ingin Anda duplikasi?',
    'Disallow login form' => 'Larang formulir masuk',
    'Start' => 'Mulai',
    'End' => 'Selesai',
    'Task age in days' => 'Usia tugas dalam hari',
    'Days in this column' => 'Hari dalam kolom ini',
    '%dd' => '%dd',
    'Add a new link' => 'Tambah tautan baru',
    'Do you really want to remove this link: "%s"?' => 'Apakah Anda yakin mau menghapus tautan ini: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Apakah Anda yakin mau menghapus tautan ini dengan tugas #%d ?',
    'Field required' => 'Bidang dibutuhkan',
    'Link added successfully.' => 'Tautan berhasil ditambahkan.',
    'Link updated successfully.' => 'Tautan berhasil diperbarui.',
    'Link removed successfully.' => 'Tautan berhasil dihapus.',
    'Link labels' => 'Label tautan',
    'Link modification' => 'Modifikasi tautan',
    'Opposite label' => 'Label berlawanan',
    'Remove a link' => 'Hapus tautan',
    'The labels must be different' => 'Label harus berbeda',
    'There is no link.' => 'Tidak ada tautan.',
    'This label must be unique' => 'Label ini harus unik',
    'Unable to create your link.' => 'Tidak dapat membuat tautan Anda.',
    'Unable to update your link.' => 'Tidak dapat memperbarui tautan Anda.',
    'Unable to remove this link.' => 'Tidak dapat menghapus tautan ini.',
    'relates to' => 'berhubungan dengan',
    'blocks' => 'blokir',
    'is blocked by' => 'diblokir oleh',
    'duplicates' => 'duplikat',
    'is duplicated by' => 'diduplikasi oleh',
    'is a child of' => 'anak dari',
    'is a parent of' => 'induk dari',
    'targets milestone' => 'target batu pijakan',
    'is a milestone of' => 'adalah batu pijakan dari',
    'fixes' => 'perbaikan',
    'is fixed by' => 'diperbaiki oleh',
    'This task' => 'Tugas ini',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Perluas tugas',
    'Collapse tasks' => 'Tutup tugas',
    'Expand/collapse tasks' => 'Perluas/tutup tugas',
    'Close dialog box' => 'Tutup kotak dialog',
    'Submit a form' => 'Kirim formulir',
    'Board view' => 'Tampilan papan',
    'Keyboard shortcuts' => 'Pintasan keyboard',
    'Open board switcher' => 'Buka switcher papan',
    'Application' => 'Aplikasi',
    'Compact view' => 'Tampilan kompak',
    'Horizontal scrolling' => 'Gulir horizontal',
    'Compact/wide view' => 'Tampilan kompak/lebar',
    'Currency' => 'Mata uang',
    'Personal project' => 'Proyek pribadi',
    'AUD - Australian Dollar' => 'AUD - Dolar Australia',
    'CAD - Canadian Dollar' => 'CAD - Dolar Kanada',
    'CHF - Swiss Francs' => 'CHF - Francs Swiss',
    'Custom Stylesheet' => 'Kustomisasi CSS',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Poundsterling Inggris',
    'INR - Indian Rupee' => 'INR - Rupe India',
    'JPY - Japanese Yen' => 'JPY - Yen Jepang',
    'NZD - New Zealand Dollar' => 'NZD - Dolar Selandia baru',
    'PEN - Peruvian Sol' => 'PEN - Sol Peru',
    'RSD - Serbian dinar' => 'RSD - Dinar Serbia',
    'CNY - Chinese Yuan' => 'CNY - Yuan Tiongkok',
    'USD - US Dollar' => 'USD - Dolar Amerika',
    'VES - Venezuelan Bolívar' => 'VES - Bolivar Venezuela',
    'Destination column' => 'Kolom tujuan',
    'Move the task to another column when assigned to a user' => 'Pindahkan tugas ke kolom lain saat ditugaskan ke pengguna',
    'Move the task to another column when assignee is cleared' => 'Pindahkan tugas ke kolom lain saat orang yang ditugaskan kosong',
    'Source column' => 'Sumber kolom',
    'Transitions' => 'Transisi',
    'Executer' => 'Eksekusi',
    'Time spent in the column' => 'Waktu yang dihabiskan dalam kolom',
    'Task transitions' => 'Transisi tugas',
    'Task transitions export' => 'Ekspor transisi tugas',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Laporan ini berisi semua kolom yang pindah untuk setiap tugas dengan tanggal, pengguna dan waktu yang dihabiskan untuk setiap transisi.',
    'Currency rates' => 'Nilai tukar mata uang',
    'Rate' => 'Tarif',
    'Change reference currency' => 'Ganti referensi mata uang',
    'Reference currency' => 'Referensi mata uang',
    'The currency rate has been added successfully.' => 'Nilai tukar mata uang berhasil ditambahkan.',
    'Unable to add this currency rate.' => 'Tidak dapat menambahkan nilai tukar mata uang',
    'Webhook URL' => 'URL Webhook',
    '%s removed the assignee of the task %s' => '%s menghapus penugasan dari tugas %s',
    'Information' => 'Informasi',
    'Check two factor authentication code' => 'Cek dua faktor kode otentifikasi',
    'The two factor authentication code is not valid.' => 'Kode dua faktor kode otentifikasi tidak sesuai.',
    'The two factor authentication code is valid.' => 'Kode dua faktor kode otentifikasi sesuai.',
    'Code' => 'Kode',
    'Two factor authentication' => 'Dua faktor otentifikasi',
    'This QR code contains the key URI: ' => 'Kode QR ini mengandung kunci URI: ',
    'Check my code' => 'Periksa kode saya',
    'Secret key: ' => 'Kunci rahasia: ',
    'Test your device' => 'Uji perangkat Anda',
    'Assign a color when the task is moved to a specific column' => 'Tetapkan warna ketika tugas tersebut dipindahkan ke kolom tertentu',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Grafik Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Grafik ini menunjukkan kompleksitas tugas dari waktu ke waktu (Sisa Pekerjaan).',
    'Screenshot taken %s' => 'Screenshot diambil %s',
    'Add a screenshot' => 'Tambah screenshot',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Ambil screenshot dan tekan CTRL+V atau ⌘+V untuk ditempel di sini.',
    'Screenshot uploaded successfully.' => 'Screenshot berhasil diunggah.',
    'SEK - Swedish Krona' => 'SEK - Krona Swedia',
    'Identifier' => 'Identifier',
    'Disable two factor authentication' => 'Matikan dua faktor otentifikasi',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Apakah Anda yakin mau mematikan dua faktor otentifikasi untuk pengguna ini: "%s"?',
    'Edit link' => 'Edit tautan',
    'Start to type task title...' => 'Mulai mengetik judul tugas...',
    'A task cannot be linked to itself' => 'Tugas tidak dapat dikaitkan dengan dirinya sendiri',
    'The exact same link already exists' => 'Tautan yang sama persis sudah ada',
    'Recurrent task is scheduled to be generated' => 'Tugas berulang dijadwalkan untuk di generate',
    'Score' => 'Skor',
    'The identifier must be unique' => 'Identifier harus unik',
    'This linked task id doesn\'t exists' => 'ID tugas terkait tidak ada',
    'This value must be alphanumeric' => 'Nilai harus alfanumerik',
    'Edit recurrence' => 'Edit pengulangan',
    'Generate recurrent task' => 'Generate tugas berulang',
    'Trigger to generate recurrent task' => 'Pemicu untuk menghasilkan tugas berulang',
    'Factor to calculate new due date' => 'Faktor untuk menghitung tanggal jatuh tempo baru',
    'Timeframe to calculate new due date' => 'Jangka waktu untuk menghitung tanggal jatuh tempo baru',
    'Base date to calculate new due date' => 'Tanggal dasar untuk menghitung tanggal jatuh tempo baru',
    'Action date' => 'Tanggal aksi',
    'Base date to calculate new due date: ' => 'Tanggal dasar untuk menghitung tanggal jatuh tempo baru: ',
    'This task has created this child task: ' => 'Tugas ini telah membuat tugas anak ini: ',
    'Day(s)' => 'Hari',
    'Existing due date' => 'Batas waktu yang ada',
    'Factor to calculate new due date: ' => 'Faktor untuk menghitung tanggal jatuh tempo baru: ',
    'Month(s)' => 'Bulan',
    'This task has been created by: ' => 'Tugas ini telah dibuat oleh: ',
    'Recurrent task has been generated:' => 'Tugas berulang telah di generate:',
    'Timeframe to calculate new due date: ' => 'Jangka waktu untuk menghitung tanggal jatuh tempo baru: ',
    'Trigger to generate recurrent task: ' => 'Pemicu untuk menghasilkan tugas berulang: ',
    'When task is closed' => 'Saat tugas ditutup',
    'When task is moved from first column' => 'Saat tugas dipindahkan dari kolom pertama',
    'When task is moved to last column' => 'Saat tugas dipindahkan ke kolom terakhir',
    'Year(s)' => 'Tahun',
    'Project settings' => 'Pengaturan proyek',
    'Automatically update the start date' => 'Otomatis memperbarui tanggal permulaan',
    'iCal feed' => 'Umpan iCal',
    'Preferences' => 'Preferensi',
    'Security' => 'Keamanan',
    'Two factor authentication disabled' => 'Otentifikasi dua faktor dimatikan',
    'Two factor authentication enabled' => 'Otentifikasi dua faktor dihidupkan',
    'Unable to update this user.' => 'Tidak dapat memperbarui pengguna ini.',
    'There is no user management for personal projects.' => 'Tidak ada manajemen pengguna untuk proyek-proyek pribadi.',
    'User that will receive the email' => 'Pengguna yang akan menerima email',
    'Email subject' => 'Subyek Email',
    'Date' => 'Tanggal',
    'Add a comment log when moving the task between columns' => 'Menambahkan log komentar ketika memindahkan tugas antara kolom',
    'Move the task to another column when the category is changed' => 'Pindahkan tugas ke kolom lain ketika kategori berubah',
    'Send a task by email to someone' => 'Kirim tugas melalui email ke seseorang',
    'Reopen a task' => 'Buka kembali tugas',
    'Notification' => 'Pemberitahuan',
    '%s moved the task #%d to the first swimlane' => '%s memindahkan tugas #%d ke swimlane pertama',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s memindahkan tugas %s ke swimlane pertama',
    '%s moved the task %s to the swimlane "%s"' => '%s memindahkan tugas %s ke swimlane "%s"',
    'This report contains all subtasks information for the given date range.' => 'Laporan ini berisi semua informasi sub-tugas untuk rentang tanggal tertentu.',
    'This report contains all tasks information for the given date range.' => 'Laporan ini berisi semua informasi tugas untuk rentang tanggal tertentu.',
    'Project activities for %s' => 'Aktifitas proyek untuk "%s"',
    'view the board on Kanboard' => 'lihat papan di Kanboard',
    'The task has been moved to the first swimlane' => 'Tugas telah dipindahkan ke swimlane pertama',
    'The task has been moved to another swimlane:' => 'Tugas telah dipindahkan ke swimlane lain:',
    'New title: %s' => 'Judul baru: %s',
    'The task is not assigned anymore' => 'Tugas tidak ditugaskan lagi',
    'New assignee: %s' => 'Penerima baru: %s',
    'There is no category now' => 'Tidak ada kategori untuk saat ini',
    'New category: %s' => 'Kategori baru: %s',
    'New color: %s' => 'Warna baru: %s',
    'New complexity: %d' => 'Kompleksitas baru: %d',
    'The due date has been removed' => 'Tanggal jatuh tempo telah dihapus',
    'There is no description anymore' => 'Tidak ada deskripsi lagi',
    'Recurrence settings has been modified' => 'Pengaturan pengulangan telah dimodifikasi',
    'Time spent changed: %sh' => 'Waktu yang dihabiskan telah diganti: %sh',
    'Time estimated changed: %sh' => 'Perkiraan waktu telah diganti: %sh',
    'The field "%s" has been updated' => 'Bidang "%s" telah diperbarui',
    'The description has been modified:' => 'Deskripsi telah dimodifikasi',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Apakah Anda yakin mau menutup tugas "%s" beserta semua sub-tugasnya?',
    'I want to receive notifications for:' => 'Saya ingin menerima pemberitahuan untuk:',
    'All tasks' => 'Semua tugas',
    'Only for tasks assigned to me' => 'Hanya untuk tugas yang ditugaskan ke saya',
    'Only for tasks created by me' => 'Hanya untuk tugas yang dibuat oleh saya',
    'Only for tasks created by me and tasks assigned to me' => 'Hanya untuk tugas yang dibuat oleh saya dan ditugaskan ke saya',
    '%%Y-%%m-%%d' => '%%d/%%m/%%Y',
    'Total for all columns' => 'Total untuk semua kolom',
    'You need at least 2 days of data to show the chart.' => 'Anda memerlukan setidaknya 2 hari dari data yang menunjukkan grafik.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Hentikan timer',
    'Start timer' => 'Mulai timer',
    'My activity stream' => 'Aliran kegiatan saya',
    'Search tasks' => 'Cari tugas',
    'Reset filters' => 'Reset saringan',
    'My tasks due tomorrow' => 'Tugas saya yang berakhir besok',
    'Tasks due today' => 'Tugas yang berakhir hari ini',
    'Tasks due tomorrow' => 'Tugas yang berakhir besok',
    'Tasks due yesterday' => 'Tugas yang berakhir kemarin',
    'Closed tasks' => 'Tugas yang ditutup',
    'Open tasks' => 'Tugas terbuka',
    'Not assigned' => 'Tidak ditugaskan',
    'View advanced search syntax' => 'Lihat sintaks pencarian lanjutan',
    'Overview' => 'Ringkasan',
    'Board/Calendar/List view' => 'Tampilan Papan/Kalender/Daftar',
    'Switch to the board view' => 'Beralih ke tampilan papan',
    'Switch to the list view' => 'Beralih ke tampilan daftar',
    'Go to the search/filter box' => 'Pergi ke kotak pencarian/saringan',
    'There is no activity yet.' => 'Belum ada aktifitas.',
    'No tasks found.' => 'Tidak ada tugas yang ditemukan.',
    'Keyboard shortcut: "%s"' => 'Pintasan keyboard: "%s"',
    'List' => 'Daftar',
    'Filter' => 'Saringan',
    'Advanced search' => 'Pencarian lanjutan',
    'Example of query: ' => 'Contoh dari query : ',
    'Search by project: ' => 'Cari berdasarkan proyek: ',
    'Search by column: ' => 'Cari berdasarkan kolom: ',
    'Search by assignee: ' => 'Cari berdasarkan penerima tugas: ',
    'Search by color: ' => 'Cari berdasarkan warna: ',
    'Search by category: ' => 'Cari berdasarkan kategori: ',
    'Search by description: ' => 'Cari berdasarkan deskripsi: ',
    'Search by due date: ' => 'Cari berdasarkan tanggal jatuh tempo: ',
    'Average time spent in each column' => 'Rata-rata waktu yang dihabiskan dalam setiap kolom',
    'Average time spent' => 'Rata-rata waktu yang dihabiskan',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Grafik ini menunjukkan rata-rata waktu yang dihabiskan dalam setiap kolom untuk %d tugas terakhir.',
    'Average Lead and Cycle time' => 'Rata-rata Lead dan Cycle time',
    'Average lead time: ' => 'Rata-rata lead time: ',
    'Average cycle time: ' => 'Rata-rata cycle time: ',
    'Cycle Time' => 'Cycle Time',
    'Lead Time' => 'Lead Time',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Grafik ini menunjukkan rata-rata waktu lead dan cycle time untuk %d tugas terakhir dari waktu ke waktu.',
    'Average time into each column' => 'Rata-rata waktu ke setiap kolom',
    'Lead and cycle time' => 'Lead dan cycle time',
    'Lead time: ' => 'Lead time: ',
    'Cycle time: ' => 'Cycle time: ',
    'Time spent in each column' => 'Waktu yang dihabiskan di setiap kolom',
    'The lead time is the duration between the task creation and the completion.' => 'Lead time adalah durasi antara pembuatan tugas dan penyelesaian.',
    'The cycle time is the duration between the start date and the completion.' => 'Cycle time adalah durasi antara tanggal mulai dan tanggal penyelesaian.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Jika tugas tidak ditutup, waktu saat ini akan digunakan sebagai pengganti tanggal penyelesaian.',
    'Set the start date automatically' => 'Secara otomatis mengatur tanggal mulai',
    'Edit Authentication' => 'Edit Otentifikasi',
    'Remote user' => 'Pengguna jauh',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Pengguna jauh tidak menyimpan kata sandi mereka dalam basis data Kanboard, contoh: akun LDAP, Google dan Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Jika anda mencentang kotak "Larang formulir login", kredensial masuk ke formulis login akan diabaikan.',
    'Default task color' => 'Warna tugas default',
    'This feature does not work with all browsers.' => 'Fitur ini tidak dapat digunakan di semua peramban',
    'There is no destination project available.' => 'Tidak ada tujuan proyek yang tersedia.',
    'Trigger automatically subtask time tracking' => 'Otomatis memicu pelacakan waktu untuk sub-tugas',
    'Include closed tasks in the cumulative flow diagram' => 'Sertakan tugas yang ditutup dalam diagram alir kumulatif',
    'Current swimlane: %s' => 'Swimlane saat ini: %s',
    'Current column: %s' => 'Kolom saat ini: %s',
    'Current category: %s' => 'Kategori saat ini: %s',
    'no category' => 'tidak ada kategori',
    'Current assignee: %s' => 'Orang yang ditugaskan saat ini: %s',
    'not assigned' => 'belum ditugaskan',
    'Author:' => 'Penulis:',
    'contributors' => 'kontributor',
    'License:' => 'Lisensi:',
    'License' => 'Lisensi',
    'Enter the text below' => 'Masukkan teks di bawah',
    'Start date:' => 'Tanggal mulai:',
    'Due date:' => 'Batas waktu:',
    'People who are project managers' => 'Orang-orang yang menjadi manajer proyek',
    'People who are project members' => 'Orang-orang yang menjadi anggota proyek',
    'NOK - Norwegian Krone' => 'NOK - Krone Norwegia',
    'Show this column' => 'Perlihatkan kolom ini',
    'Hide this column' => 'Sembunyikan kolom ini',
    'End date' => 'Waktu berakhir',
    'Users overview' => 'Ringkasan pengguna',
    'Members' => 'Anggota',
    'Shared project' => 'Proyek bersama',
    'Project managers' => 'Manajer proyek',
    'Projects list' => 'Daftar proyek',
    'End date:' => 'Waktu berakhir:',
    'Change task color when using a specific task link' => 'Ganti warna tugas ketika menggunakan tautan tugas yang spesifik',
    'Task link creation or modification' => 'Tautan pembuatan atau modifikasi tugas ',
    'Milestone' => 'Milestone',
    'Reset the search/filter box' => 'Reset kotak pencarian/saringan',
    'Documentation' => 'Dokumentasi',
    'Author' => 'Penulis',
    'Version' => 'Versi',
    'Plugins' => 'Plugin',
    'There is no plugin loaded.' => 'Tidak ada plugin yang dimuat',
    'My notifications' => 'Notifikasi saya',
    'Custom filters' => 'Saringan kustom',
    'Your custom filter has been created successfully.' => 'Saringan kustom Anda berhasil dibuat',
    'Unable to create your custom filter.' => 'Tidak dapat membuat saringan kustom',
    'Custom filter removed successfully.' => 'Saringan kustom berhasil dihapus',
    'Unable to remove this custom filter.' => 'Tidak dapat menghapus saringan kustom',
    'Edit custom filter' => 'Edit saringan kustom',
    'Your custom filter has been updated successfully.' => 'Saringan kustom Anda berhasil diperbarui',
    'Unable to update custom filter.' => 'Tidak dapat memperbarui saringan kustom',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Lampiran baru pada tugas #%d: %s',
    'New comment on task #%d' => 'Komentar baru pada tugas #%d',
    'Comment updated on task #%d' => 'Komentar diperbarui pada tugas #%d',
    'New subtask on task #%d' => 'Sub-tugas baru pada tugas #%d',
    'Subtask updated on task #%d' => 'Sub-tugas diperbarui pada tugas #%d',
    'New task #%d: %s' => 'Tugas baru #%d: %s',
    'Task updated #%d' => 'Tugas diperbarui #%d',
    'Task #%d closed' => 'Tugas #%d ditutup',
    'Task #%d opened' => 'Tugas #%d dibuka',
    'Column changed for task #%d' => 'Kolom diganti untuk tugas #%d',
    'New position for task #%d' => 'Posisi baru untuk tugas #%d',
    'Swimlane changed for task #%d' => 'Swimlane diganti untuk tugas #%d',
    'Assignee changed on task #%d' => 'Orang yang ditugaskan diganti pada tugas #%d',
    '%d overdue tasks' => '%d tugas kadaluarsa',
    'No notification.' => 'Tidak ada notifikasi baru',
    'Mark all as read' => 'Tandai semua sebagai sudah dibaca',
    'Mark as read' => 'Tandai sebagai sudah dibaca',
    'Total number of tasks in this column across all swimlanes' => 'Total tugas di kolom ini untuk semua swimlane',
    'Collapse swimlane' => 'Tutup swimlane',
    'Expand swimlane' => 'Perluas swimlane',
    'Add a new filter' => 'Tambah saringan baru',
    'Share with all project members' => 'Bagikan dengan semua anggota proyek',
    'Shared' => 'Dibagikan',
    'Owner' => 'Pemilik',
    'Unread notifications' => 'Notifikasi belum terbaca',
    'Notification methods:' => 'Metode pemberitahuan',
    'Unable to read your file' => 'Tidak dapat membaca berkas Anda',
    '%d task(s) have been imported successfully.' => '%d tugas telah berhasil di impor',
    'Nothing has been imported!' => 'Tidak ada yang dapat di impor',
    'Import users from CSV file' => 'Impor pengguna dari berkas CSV',
    '%d user(s) have been imported successfully.' => '%d pengguna telah berhasil di impor',
    'Comma' => 'Koma',
    'Semi-colon' => 'Titik Koma',
    'Tab' => 'Tab',
    'Vertical bar' => 'Bar vertikal',
    'Double Quote' => 'Kutip Ganda',
    'Single Quote' => 'Kutip Satu',
    '%s attached a file to the task #%d' => '%s berkas dilampirkan untuk tugas  #%d',
    'There is no column or swimlane activated in your project!' => 'Tidak ada kolom atau swimlane aktif untuk proyek Anda',
    'Append filter (instead of replacement)' => 'Tambahkan saringan (ketimbang pengganti)',
    'Append/Replace' => 'Tambah/Ganti',
    'Append' => 'Tambahkan',
    'Replace' => 'Ganti',
    'Import' => 'Impor',
    'Change sorting' => 'ubah pengurutan',
    'Tasks Importation' => 'Importasi Tugas',
    'Delimiter' => 'Pembatas',
    'Enclosure' => 'Lampiran',
    'CSV File' => 'Berkas CSV',
    'Instructions' => 'Intruksi',
    'Your file must use the predefined CSV format' => 'Berkas Anda harus menggunakan format CSV yang telah ditetapkan',
    'Your file must be encoded in UTF-8' => 'Berkas anda harus di kodekan dalam bentuk UTF-8',
    'The first row must be the header' => 'Baris pertama harus header',
    'Duplicates are not verified for you' => 'Duplikasi tidak diverifikasikan untuk Anda',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Tanggal jatuh tempo harus menggunakan format ISO: YYYY-MM-DD',
    'Download CSV template' => 'Unduh template CSV',
    'No external integration registered.' => 'Tidak ada integrasi eksternal yang terdaftar',
    'Duplicates are not imported' => 'Duplikasi tidak diimpor',
    'Usernames must be lowercase and unique' => 'Nama pengguna harus huruf kecil dan unik',
    'Passwords will be encrypted if present' => 'Kata sandi akan di enkripsi jika ada',
    '%s attached a new file to the task %s' => '%s melampirkan berkas baru untuk tugas %s',
    'Link type' => 'Tipe tautan',
    'Assign automatically a category based on a link' => 'Otomatis menetapkan kategori berdasarkan tautan',
    'BAM - Konvertible Mark' => 'BAM - Konvertible Mark',
    'Assignee Username' => 'Nama pengguna orang yang ditugaskan',
    'Assignee Name' => 'Nama orang yang ditugaskan',
    'Groups' => 'Grup',
    'Members of %s' => 'Anggota dari %s',
    'New group' => 'Grup baru',
    'Group created successfully.' => 'Grup berhasil dibuat',
    'Unable to create your group.' => 'Tidak dapat membuat grup Anda',
    'Edit group' => 'Edit grup',
    'Group updated successfully.' => 'Grup berhasil diperbarui',
    'Unable to update your group.' => 'Tidak dapat memperbarui grup anda',
    'Add group member to "%s"' => 'Tambahkan anggota grup ke "%s"',
    'Group member added successfully.' => 'Anggota grup berhasil ditambahkan',
    'Unable to add group member.' => 'Tidak dapat menambahkan anggota grup',
    'Remove user from group "%s"' => 'Hapus pengguna dari grup "%s"',
    'User removed successfully from this group.' => 'Pengguna berhasil dihapus dari grup ini',
    'Unable to remove this user from the group.' => 'Tidak dapat menghapus pengguna ini dari grup',
    'Remove group' => 'Hapus grup',
    'Group removed successfully.' => 'Grup berhasil dihapus',
    'Unable to remove this group.' => 'Tidak dapat menghapus grup ini',
    'Project Permissions' => 'Izin Proyek',
    'Manager' => 'Manajer',
    'Project Manager' => 'Manajer Proyek',
    'Project Member' => 'Anggota Proyek',
    'Project Viewer' => 'Penonton Proyek',
    'Your account is locked for %d minutes' => 'Akun anda dikunci untuk %d menit',
    'Invalid captcha' => 'Captcha tidak sesuai',
    'The name must be unique' => 'Nama harus unik',
    'View all groups' => 'Lihat semua grup',
    'There is no user available.' => 'Tidak ada pengguna yang tersedia',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Anda yakin mau menghapus pengguna "%s" dari grup "%s"?',
    'There is no group.' => 'Tidak ada grup',
    'Add group member' => 'Tambah anggota grup',
    'Do you really want to remove this group: "%s"?' => 'Anda yakin mau menghapus grup ini: "%s"?',
    'There is no user in this group.' => 'Tidak ada pengguna dalam grup ini',
    'Permissions' => 'Izin',
    'Allowed Users' => 'Pengguna Yang Diizinkan',
    'No specific user has been allowed.' => 'Tidak ada user yang diperbolehkan secara khusus',
    'Role' => 'Peran',
    'Enter user name...' => 'Masukkan nama pengguna...',
    'Allowed Groups' => 'Grup Yang Diizinkan',
    'No group has been allowed.' => 'Tidak ada grup yang diperbolehkan secara khusus',
    'Group' => 'Grup',
    'Group Name' => 'Nama Grup',
    'Enter group name...' => 'Masukkan nama grup...',
    'Role:' => 'Peran:',
    'Project members' => 'Anggota proyek',
    '%s mentioned you in the task #%d' => '%s menyebut Anda dalam tugas #%d',
    '%s mentioned you in a comment on the task #%d' => '%s menyebut Anda dalam komentar pada tugas #%d',
    'You were mentioned in the task #%d' => 'Anda disebutkan dalam tugas #%d',
    'You were mentioned in a comment on the task #%d' => 'Anda disebutkan dalam komentar pada tugas #%d',
    'Estimated hours: ' => 'Estimasi jam: ',
    'Actual hours: ' => 'Jam sebenarnya: ',
    'Hours Spent' => 'Jam dihabiskan',
    'Hours Estimated' => 'Jam diperkirakan',
    'Estimated Time' => 'Waktu Estimasi',
    'Actual Time' => 'Waktu Sebenarnya',
    'Estimated vs actual time' => 'Estimasi vs waktu sebenarnya',
    'RUB - Russian Ruble' => 'RUB - Rubel Rusia',
    'Assign the task to the person who does the action when the column is changed' => 'Berikan tugas pada orang yang melakukan tindakan saat kolom diganti',
    'Close a task in a specific column' => 'Tutup tugas di kolom tertentu',
    'Time-based One-time Password Algorithm' => 'Algoritma Password Satu-Kali Berbasis-Waktu',
    'Two-Factor Provider: ' => 'Penyedia Dua-Faktor',
    'Disable two-factor authentication' => 'Nonaktifkan otentikasi dua-faktor',
    'Enable two-factor authentication' => 'Aktifkan otentikasi dua-faktor',
    'There is no integration registered at the moment.' => 'Tidak ada integrasi yang didaftarkan untuk saat ini',
    'Password Reset for Kanboard' => 'Reset Password untuk Kanboard',
    'Forgot password?' => 'Lupa password?',
    'Enable "Forget Password"' => 'Aktifkan "Lupa Password"',
    'Password Reset' => 'Reset Password',
    'New password' => 'Password baru',
    'Change Password' => 'Ganti Password',
    'To reset your password click on this link:' => 'Untuk reset password Anda klik tautan ini:',
    'Last Password Reset' => 'Reset Password Terakhir',
    'The password has never been reinitialized.' => 'Password tidak pernah di inisialisasi ulang',
    'Creation' => 'Pembuatan',
    'Expiration' => 'Kadaluarsa',
    'Password reset history' => 'Sejarah reset password',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Semua tugas dalam kolom "%s" dan swimlane "%s" telah berhasil ditutup',
    'Do you really want to close all tasks of this column?' => 'Apakah Anda yakin mau menutup semua tugas dalam kolom ini?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tugas dalam kolom "%s" dan swimlane "%s" akan ditutup.',
    'Close all tasks in this column and this swimlane' => 'Tutup semua tugas dalam kolom ini',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Tidak ada plugin yang mendaftarkan metode pemberitahuan proyek. Anda masih bisa mengatur pemberitahuan individu di dalam profil pengguna Anda.',
    'My dashboard' => 'Dasbor saya',
    'My profile' => 'Profil saya',
    'Project owner: ' => 'Pemilik proyek',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifier proyek adalah opsional dan harus alfanumerik, contoh: MYPROJECT.',
    'Project owner' => 'Pemilik proyek',
    'Personal projects do not have users and groups management.' => 'Proyek pribadi tidak memiliki manajemen pengguna dan grup',
    'There is no project member.' => 'Tidak ada anggota proyek',
    'Priority' => 'Prioritas',
    'Task priority' => 'Prioritas tugas',
    'General' => 'Umum',
    'Dates' => 'Tanggal',
    'Default priority' => 'Prioritas default',
    'Lowest priority' => 'Prioritas terendah',
    'Highest priority' => 'Prioritas tertinggi',
    'Close a task when there is no activity' => 'Tutup tugas jika tidak ada aktifitas',
    'Duration in days' => 'Durasi dalam hari',
    'Send email when there is no activity on a task' => 'Kirim email jika tidak ada aktifitas dalam tugas',
    'Unable to fetch link information.' => 'Tidak dapat mengambil informasi tautan',
    'Daily background job for tasks' => 'Tugas latar belakang harian untuk tugas',
    'Auto' => 'Otomatis',
    'Related' => 'Terkait',
    'Attachment' => 'Lampiran',
    'Web Link' => 'Tautan web',
    'External links' => 'Tautan eksternal',
    'Add external link' => 'Tambah tautan eksternal',
    'Type' => 'Tipe',
    'Dependency' => 'Ketergantungan',
    'Add internal link' => 'Tambah tautan internal',
    'Add a new external link' => 'Tambah tautan eksternal baru',
    'Edit external link' => 'Rubah tautan eksternal',
    'External link' => 'Tautan eksternal',
    'Copy and paste your link here...' => 'Copy dan paste tautan anda di sini...',
    'URL' => 'URL',
    'Internal links' => 'Tautan internal',
    'Assign to me' => 'Tugaskan ke saya',
    'Me' => 'Saya',
    'Do not duplicate anything' => 'Jangan menduplikasi apapun',
    'Projects management' => 'Manajemen proyek',
    'Users management' => 'Manajemen pengguna',
    'Groups management' => 'Manajemen grup',
    'Create from another project' => 'Buat dari proyek lain',
    'open' => 'buka',
    'closed' => 'tutup',
    'Priority:' => 'Prioritas',
    'Reference:' => 'Referensi',
    'Complexity:' => 'Kompleksitas',
    'Swimlane:' => 'Swimlane',
    'Column:' => 'Kolom:',
    'Position:' => 'Posisi:',
    'Creator:' => 'Pembuat:',
    'Time estimated:' => 'Estimasi waktu:',
    '%s hours' => '%s jam',
    'Time spent:' => 'Waktu yang dihabiskan',
    'Created:' => 'Dibuat:',
    'Modified:' => 'Dimodifikasi:',
    'Completed:' => 'Selesai:',
    'Started:' => 'Dimulai:',
    'Moved:' => 'Dipindahkan:',
    'Task #%d' => 'Tugas #%d',
    'Time format' => 'Format waktu',
    'Start date: ' => 'Tanggal mulai: ',
    'End date: ' => 'Tanggal berakhir: ',
    'New due date: ' => 'Tanggal jatuh tempo baru: ',
    'Start date changed: ' => 'Tanggal mulai diganti: ',
    'Disable personal projects' => 'Nonaktifkan proyek pribadi',
    'Do you really want to remove this custom filter: "%s"?' => 'Apakah Anda yakin mau menghapus saringan kustom: "%s"?',
    'Remove a custom filter' => 'Hapus saringan kustom',
    'User activated successfully.' => 'Pengguna berhasil diaktifkan.',
    'Unable to enable this user.' => 'Tidak dapat mengaktifkan pengguna ini.',
    'User disabled successfully.' => 'Pengguna berhasil dinonaktifkan.',
    'Unable to disable this user.' => 'Tidak dapat menonaktifkan pengguna ini.',
    'All files have been uploaded successfully.' => 'Semua berkas berhasil di unggah.',
    'The maximum allowed file size is %sB.' => 'Maksimum ukuran berkas yang diiziinkan adalah %sB.',
    'Drag and drop your files here' => 'Drag and drop file Anda di sini',
    'choose files' => 'pilih berkas',
    'View profile' => 'Lihat profil',
    'Two Factor' => 'Dua Faktor',
    'Disable user' => 'Nonaktifkan pengguna',
    'Do you really want to disable this user: "%s"?' => 'Anda yakin mau menonaktifkan pengguna ini: "%s"?',
    'Enable user' => 'Aktifkan pengguna',
    'Do you really want to enable this user: "%s"?' => 'Anda yakin mau mengaktifkan pengguna ini: "%s"?',
    'Download' => 'Unduh',
    'Uploaded: %s' => 'Diunggah: %s',
    'Size: %s' => 'Ukuran: %s',
    'Uploaded by %s' => 'Diunggah oleh %s',
    'Filename' => 'Nama berkas',
    'Size' => 'Ukuran',
    'Column created successfully.' => 'Kolom berhasil dibuat.',
    'Another column with the same name exists in the project' => 'Ada kolom lain dengan nama yang sama di proyek ini',
    'Default filters' => 'Saringan default',
    'Your board doesn\'t have any columns!' => 'Papan Anda tidak memiliki kolom!',
    'Change column position' => 'Ganti posisi kolom',
    'Switch to the project overview' => 'Pindah ke ringkasan proyek',
    'User filters' => 'Saringan pengguna',
    'Category filters' => 'Saringan kategori',
    'Upload a file' => 'Unggah berkas',
    'View file' => 'Lihat berkas',
    'Last activity' => 'Aktivitas terakhir',
    'Change subtask position' => 'Ganti posisi sub-tugas',
    'This value must be greater than %d' => 'Nilai ini harus lebih besar dari %d',
    'Another swimlane with the same name exists in the project' => 'Swimlane lain dengan nama yang sama sudah ada di proyek ini',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Contoh: https://contoh.kanboard.org/ (digunakan untuk menghasilkan URL yang absolut',
    'Actions duplicated successfully.' => 'Tindakan berhasil di duplikasi.',
    'Unable to duplicate actions.' => 'Tidak bisa menduplikasi tindakan.',
    'Add a new action' => 'Tambahkan tindakan baru',
    'Import from another project' => 'Impor dari proyek lain',
    'There is no action at the moment.' => 'Belum ada tindakan pada saat ini.',
    'Import actions from another project' => 'Impor tindakan dari proyek lain',
    'There is no available project.' => 'Tidak ada proyek yang tersedia',
    'Local File' => 'Berkas Lokal',
    'Configuration' => 'Konfigurasi',
    'PHP version:' => 'Versi PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versi sistem operasi:',
    'Database version:' => 'Versi database:',
    'Browser:' => 'Peramban:',
    'Task view' => 'Tampilan Tugas',
    'Edit task' => 'Edit tugas',
    'Edit description' => 'Edit deskripsi',
    'New internal link' => 'Tautan internal baru',
    'Display list of keyboard shortcuts' => 'Tampilkan daftar pintasan keyboard',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Unggah foto avatar saya',
    'Remove my image' => 'Hapus foto saya',
    'The OAuth2 state parameter is invalid' => 'Status parameter OAuth2 tidak sesuai',
    'User not found.' => 'Pengguna tidak ditemukan.',
    'Search in activity stream' => 'Cari di saluran aktivitas',
    'My activities' => 'Aktivitas saya',
    'Activity until yesterday' => 'Aktivitas sampai kemarin',
    'Activity until today' => 'Aktivitas sampai hari ini',
    'Search by creator: ' => 'Cari berdasarkan pembuat: ',
    'Search by creation date: ' => 'Cari berdasarkan tanggal pembuatan: ',
    'Search by task status: ' => 'Cari berdasarkanstatus tugas: ',
    'Search by task title: ' => 'Cari berdasarkan judul tugas: ',
    'Activity stream search' => 'Pencarian saluran aktivitas',
    'Projects where "%s" is manager' => 'Proyek dimana "%s" adalah manajernya',
    'Projects where "%s" is member' => 'Proyek dimana "%s" adalah anggotanya',
    'Open tasks assigned to "%s"' => 'Tugas terbuka ditugaskan pada "%s"',
    'Closed tasks assigned to "%s"' => 'Tugas tertutup ditugaskan pada "%s"',
    'Assign automatically a color based on a priority' => 'Berikan warna otomatis berdasarkan prioritas',
    'Overdue tasks for the project(s) "%s"' => 'Tugas yang kadaluarsa untuk proyek "%s"',
    'Upload files' => 'Unggah berkas',
    'Installed Plugins' => 'Plugin terpasang',
    'Plugin Directory' => 'Direktori Plugin',
    'Plugin installed successfully.' => 'Plugin berhasil dipasang.',
    'Plugin updated successfully.' => 'Plugin berhasil diperbarui.',
    'Plugin removed successfully.' => 'Plugin berhasil dihapus.',
    'Subtask converted to task successfully.' => 'Sub-tugas berhasil diubah menjadi tugas.',
    'Unable to convert the subtask.' => 'Tidak dapat mengubah sub-tugas.',
    'Unable to extract plugin archive.' => 'Tidak bisa mengekstrak arsip plugin.',
    'Plugin not found.' => 'Plugin tidak ditemukan.',
    'You don\'t have the permission to remove this plugin.' => 'Anda tidak memiliki izin untuk menghapus plugin ini.',
    'Unable to download plugin archive.' => 'Tidak dapat mengunduh arsip plugin.',
    'Unable to write temporary file for plugin.' => 'Tidak dapat menulis berkas sementara untuk plugin.',
    'Unable to open plugin archive.' => 'Tidak dapat membuka arsip plugin.',
    'There is no file in the plugin archive.' => 'Tidak ada berkas di dalam arsip plugin.',
    'Create tasks in bulk' => 'Buat tugas sekaligus',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Instalasi Kanboard Anda tidak diatur untuk memasang plugin dari antar muka pengguna.',
    'There is no plugin available.' => 'Tidak ada plugin yang tersedia.',
    'Install' => 'Pasang',
    'Update' => 'Perbarui',
    'Up to date' => 'Terbaru',
    'Not available' => 'Tidak tersedia',
    'Remove plugin' => 'Hapus plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Anda yakin ingin menghapus plugin ini: "%s"?',
    'Uninstall' => 'Lepaskan',
    'Listing' => 'Daftar',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Atur proyek',
    'Convert to task' => 'Ubah menjadi tugas',
    'Convert sub-task to task' => 'Ubah sub-tugas menjadi tugas',
    'Do you really want to convert this sub-task to a task?' => 'Anda yakin ingin mengubah sub-tugas ini menjadi tugas?',
    'My task title' => 'Judul tugas saya',
    'Enter one task by line.' => 'Masukkan satu tugas berdasarkan baris.',
    'Number of failed login:' => 'Jumlah login yang gagal:',
    'Account locked until:' => 'Akun terkunci hingga:',
    'Email settings' => 'Pengaturan email',
    'Email sender address' => 'Alamat pengirim email',
    'Email transport' => 'Transportasi email',
    'Webhook token' => 'Token Webhook',
    'Project tags management' => 'Manajemen tag proyek',
    'Tag created successfully.' => 'Tag berhasil dibuat.',
    'Unable to create this tag.' => 'Tidak dapat membuat tag ini.',
    'Tag updated successfully.' => 'Tag berhasil diperbarui',
    'Unable to update this tag.' => 'Tidak dapat memperbarui tag ini.',
    'Tag removed successfully.' => 'Tag berhasil dihapus.',
    'Unable to remove this tag.' => 'Tidak dapat menghapus tag ini.',
    'Global tags management' => 'Manajemen tag global',
    'Tags' => 'Tag',
    'Tags management' => 'Manajemen tag',
    'Add new tag' => 'Tambah tag baru',
    'Edit a tag' => 'Edit tag',
    'Project tags' => 'Tag proyek',
    'There is no specific tag for this project at the moment.' => 'Saat ini tidak ada tag yang spesifik pada proyek ini.',
    'Tag' => 'Tag',
    'Remove a tag' => 'Hapus tag',
    'Do you really want to remove this tag: "%s"?' => 'Anda yakin ingin menghapus tag ini: "%s"?',
    'Global tags' => 'Tag global',
    'There is no global tag at the moment.' => 'Saat ini tidak ada tag global.',
    'This field cannot be empty' => 'Bidang ini tidak boleh kosong',
    'Close a task when there is no activity in a specific column' => 'Tutup tugas saat tidak ada aktivitas di kolom tertentu',
    '%s removed a subtask for the task #%d' => '%s menghapus sub-tugas untuk tugas #%d',
    '%s removed a comment on the task #%d' => '%s menghapus komentar pada tugas #%d',
    'Comment removed on task #%d' => 'Komentar dihapus pada tugas #%d',
    'Subtask removed on task #%d' => 'Sub-tugas dihapus pada tugas #%d',
    'Hide tasks in this column in the dashboard' => 'Sembunyikan tugas-tugas di kolom ini di dasbor',
    '%s removed a comment on the task %s' => '%s menghapus komentar pada tugas %s',
    '%s removed a subtask for the task %s' => '%s menghapus sub-tugas untuk tugas %s',
    'Comment removed' => 'Komentar dihapus',
    'Subtask removed' => 'Sub-tugas dihapus',
    '%s set a new internal link for the task #%d' => '%s memasang tautan internal baru untuk tugas #%d',
    '%s removed an internal link for the task #%d' => '%s menghapus tautan internal untuk tugas #%d',
    'A new internal link for the task #%d has been defined' => 'Tautan internal baru untuk tugas #%d telah ditentukan',
    'Internal link removed for the task #%d' => 'Tautan internal untuk tugas #%d telah dihapus',
    '%s set a new internal link for the task %s' => '%s memasang tautan internal baru untuk tugas %s',
    '%s removed an internal link for the task %s' => '%s menghapus tautan internal untuk tugas %s',
    'Automatically set the due date on task creation' => 'Otomatis memasang tanggal kadaluarsa saat pembuatan tugas',
    'Move the task to another column when closed' => 'Pindahkan tugas ke kolom lain saat ditutup',
    'Move the task to another column when not moved during a given period' => 'Pindahkan tugas ke kolom lain saat tidak dipindahkan selama periode yang diberikan',
    'Dashboard for %s' => 'Dasbor untuk %s',
    'Tasks overview for %s' => 'Ringkasan tugas-tugas untuk %s',
    'Subtasks overview for %s' => 'Ringkasan sub-tugas untuk %s',
    'Projects overview for %s' => 'Ringkasan proyek untuk %s',
    'Activity stream for %s' => 'Arus aktivitas untuk %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Berikan warna saat tugas dipindahkan ke swimlane tertentu',
    'Assign a priority when the task is moved to a specific swimlane' => 'Berikan prioritas saat tugas dipindahkan ke swimlane tertentu',
    'User unlocked successfully.' => 'Berhasil membuka blokir pengguna.',
    'Unable to unlock the user.' => 'Tidak bisa membuka blokir pengguna.',
    'Move a task to another swimlane' => 'Pindahkan tugas ke swimlane lain',
    'Creator Name' => 'Nama Pembuat',
    'Time spent and estimated' => 'Waktu yang dihabiskan dan diperkirakan',
    'Move position' => 'Pindahkan posisi',
    'Move task to another position on the board' => 'Pindahkan tugas ke posisi lain di dalam papan',
    'Insert before this task' => 'Masukkan sebelum tugas ini',
    'Insert after this task' => 'Masukkan setelah tugas ini',
    'Unlock this user' => 'Buka pengguna ini',
    'Custom Project Roles' => 'Peran Proyek Kustom',
    'Add a new custom role' => 'Tambahkan peran kustom baru',
    'Restrictions for the role "%s"' => 'Batasan untuk peran "%s"',
    'Add a new project restriction' => 'Tambahkan batasan proyek baru',
    'Add a new drag and drop restriction' => 'Tambahkan batasan drag and drop baru',
    'Add a new column restriction' => 'Tambahkan batasan kolom baru',
    'Edit this role' => 'Edit peran ini',
    'Remove this role' => 'Hapus peran ini',
    'There is no restriction for this role.' => 'Tidak ada batasan untuk peran ini.',
    'Only moving task between those columns is permitted' => 'Hanya diizinkan untuk memindahkan tugas diantara kolom-kolom tersebut',
    'Close a task in a specific column when not moved during a given period' => 'Tutup tugas pada kolom tertentu saat tidak dipindahkan pada periode yang diberikan',
    'Edit columns' => 'Edit kolom',
    'The column restriction has been created successfully.' => 'Batasan kolom berhasil dibuat.',
    'Unable to create this column restriction.' => 'Tidak dapat membuat batasan kolom ini.',
    'Column restriction removed successfully.' => 'Batasan kolom berhasil dihapus.',
    'Unable to remove this restriction.' => 'Gagal menghapus batasan ini.',
    'Your custom project role has been created successfully.' => 'Peran kustom proyek Anda berhasil dibuat.',
    'Unable to create custom project role.' => 'Tidak dapat membuat peran proyek kustom.',
    'Your custom project role has been updated successfully.' => 'Peran proyek kustom Anda berhasil diperbarui.',
    'Unable to update custom project role.' => 'Tidak dapat memperbarui peran kustom proyek',
    'Custom project role removed successfully.' => 'Peran kustom proyek berhasil dihapus.',
    'Unable to remove this project role.' => 'Tidak dapat menghapus peran proyek ini.',
    'The project restriction has been created successfully.' => 'Batasan proyek ini berhasil dibuat.',
    'Unable to create this project restriction.' => 'Tidak dapat membuat batasan proyek ini.',
    'Project restriction removed successfully.' => 'Batasan proyek berhasil dihapus.',
    'You cannot create tasks in this column.' => 'Anda tidak dapat membuat tugas di kolom ini.',
    'Task creation is permitted for this column' => 'Pembuatan tugas diizinkan untuk kolom ini',
    'Closing or opening a task is permitted for this column' => 'Penutupan atau pembukaan tugas diizinkan untuk kolom ini',
    'Task creation is blocked for this column' => 'Pembuatan tugas diblokir dari kolom ini',
    'Closing or opening a task is blocked for this column' => 'Penutupan atau pembukaan tugas diblokir di kolom ini',
    'Task creation is not permitted' => 'Oembuatan tugas tidak diizinkan',
    'Closing or opening a task is not permitted' => 'Penutupan atau pembukaan tugas tidak diizinkan',
    'New drag and drop restriction for the role "%s"' => 'Larangan drag and drop baru untuk peran "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Orang-orang dengan peran ini dapat memindahkan tugas diantara kolom sumber dan destinasi.',
    'Remove a column restriction' => 'Hapus pembatasan kolom',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Anda yakin ingin menghapus pembatasan kolom ini: "%s" ke "%s"?',
    'New column restriction for the role "%s"' => 'Kolom pembatasan baru untuk peran "%s"',
    'Rule' => 'Aturan',
    'Do you really want to remove this column restriction?' => 'Anda yakin ingin menghapus pembatasan kolom ini?',
    'Custom roles' => 'Peran kustom',
    'New custom project role' => 'Peran kustom proyek baru',
    'Edit custom project role' => 'Edit peran kustom proyek',
    'Remove a custom role' => 'Hapus peran kustom',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Anda yakin ingin menghapus peran kustom ini: "%s"? Semua orang yang memiliki peran ini akan berubah menjadi anggota proyek.',
    'There is no custom role for this project.' => 'Tidak ada peran kustom untuk proyek ini.',
    'New project restriction for the role "%s"' => 'Batasan proyek baru untuk peran "%s"',
    'Restriction' => 'Pembatasan',
    'Remove a project restriction' => 'Hapus batasan proyek',
    'Do you really want to remove this project restriction: "%s"?' => 'Anda yakin ingin menghapus pembatasan proyek ini: "%s"?',
    'Duplicate to multiple projects' => 'Duplikasikan ke banyak proyek',
    'This field is required' => 'Bidang ini dibutuhkan',
    'Moving a task is not permitted' => 'Memindahkan tugas tidak diizinkan',
    'This value must be in the range %d to %d' => 'Nilai ini harus berkisar antara %d hingga %d',
    'You are not allowed to move this task.' => 'Anda tidak diizinkan untuk memindahkan tugas ini.',
    'API User Access' => 'API Akses Pengguna',
    'Preview' => 'Pratinjau',
    'Write' => 'Tulis',
    'Write your text in Markdown' => 'Tuliskan teks Anda di Markdown',
    'No personal API access token registered.' => 'Tidak ada token akses API personal yang terdaftar.',
    'Your personal API access token is "%s"' => 'Token akses API personal Anda adalah "%s"',
    'Remove your token' => 'Hapus token Anda',
    'Generate a new token' => 'Generate token baru',
    'Showing %d-%d of %d' => 'Menampilkan %d-%d of %d',
    'Outgoing Emails' => 'Email Keluar',
    'Add or change currency rate' => 'Tambah atau ubah nilai mata uang',
    'Reference currency: %s' => 'referensi Mata uang: %s',
    'Add custom filters' => 'Tambahkan filter khusus',
    'Export' => 'Export',
    'Add link label' => 'Tambahkan label tautan',
    'Incompatible Plugins' => 'Plugin Tidak Kompatibel',
    'Compatibility' => 'Kesesuaian',
    'Permissions and ownership' => 'Izin dan kepemilikan',
    'Priorities' => 'Prioritas',
    'Close this window' => 'Tutup jendela ini',
    'Unable to upload this file.' => 'Tidak dapat mengupload file ini.',
    'Import tasks' => 'Impor tugas',
    'Choose a project' => 'Pilih sebuah proyek',
    'Profile' => 'Profil',
    'Application role' => 'Peran aplikasi',
    '%d invitations were sent.' => '%d undangan telah dikirim.',
    '%d invitation was sent.' => '%d undangan telah dikirim.',
    'Unable to create this user.' => 'Tidak dapat membuat pengguna.',
    'Kanboard Invitation' => 'Undangan Kanboard',
    'Visible on dashboard' => 'Terlihat pada dashboard',
    'Created at:' => 'Dibuat pada:',
    'Updated at:' => 'Diperbarui pada:',
    'There is no custom filter.' => 'Tidak ada filter khusus.',
    'New User' => 'Pengguna Baru',
    'Authentication' => 'Otentikasi',
    'If checked, this user will use a third-party system for authentication.' => 'Jika dicentang, pengguna ini akan menggunakan sistem pihak ketiga untuk otentikasi.',
    'The password is necessary only for local users.' => 'Kata sandi hanya diperlukan untuk pengguna lokal.',
    'You have been invited to register on Kanboard.' => 'Anda telah diundang untuk mendaftar di Kanboard.',
    'Click here to join your team' => 'Klik di sini untuk bergabung dengan tim Anda',
    'Invite people' => 'Undang orang',
    'Emails' => 'Email',
    'Enter one email address by line.' => 'Masukkan satu alamat email per baris.',
    'Add these people to this project' => 'Tambahkan orang-orang ini ke proyek ini',
    'Add this person to this project' => 'Tambahkan orang ini ke proyek ini',
    'Sign-up' => 'Daftar',
    'Credentials' => 'Credential',
    'New user' => 'Pengguna baru',
    'This username is already taken' => 'Nama pengguna ini sudah dipakai',
    'Your profile must have a valid email address.' => 'Profil Anda harus memiliki alamat email yang valid.',
    'TRL - Turkish Lira' => 'TRL - Lira Turki',
    'The project email is optional and could be used by several plugins.' => 'Email proyek adalah opsional dan dapat digunakan oleh beberapa plugin.',
    'The project email must be unique across all projects' => 'Email proyek harus unik di semua proyek',
    'The email configuration has been disabled by the administrator.' => 'Konfigurasi email telah dinonaktifkan oleh administrator.',
    'Close this project' => 'Tutup proyek ini',
    'Open this project' => 'Buka proyek ini',
    'Close a project' => 'Tutup proyek',
    'Do you really want to close this project: "%s"?' => 'Anda yakin ingin menutup proyek ini: "%s"?',
    'Reopen a project' => 'Buka kembali proyek',
    'Do you really want to reopen this project: "%s"?' => 'Anda yakin ingin membuka kembali proyek ini: "%s"?',
    'This project is open' => 'Proyek ini terbuka',
    'This project is closed' => 'Proyek ini ditutup',
    'Unable to upload files, check the permissions of your data folder.' => 'Tidak dapat mengunggah file, periksa izin folder data Anda.',
    'Another category with the same name exists in this project' => 'Kategori lain dengan nama yang sama ada dalam proyek ini',
    'Comment sent by email successfully.' => 'Komentar berhasil dikirim melalui email.',
    'Sent by email to "%s" (%s)' => 'Dikirim melalui email ke "%s" (%s)',
    'Unable to read uploaded file.' => 'Tidak dapat membaca file yang diunggah.',
    'Database uploaded successfully.' => 'Database berhasil diunggah.',
    'Task sent by email successfully.' => 'Tugas berhasil dikirim melalui email.',
    'There is no category in this project.' => 'Tidak ada kategori dalam proyek ini.',
    'Send by email' => 'Kirim melalui email',
    'Create and send a comment by email' => 'Buat dan kirim komentar melalui email',
    'Subject' => 'Subjek',
    'Upload the database' => 'Unggah database',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Anda dapat mengunggah basis data Sqlite yang diunduh sebelumnya (format Gzip).',
    'Database file' => 'File database',
    'Upload' => 'Unggah',
    'Your project must have at least one active swimlane.' => 'Proyek Anda harus memiliki setidaknya satu swimlane aktif.',
    'Project: %s' => 'Proyek: %s',
    'Automatic action not found: "%s"' => 'Tindakan otomatis tidak ditemukan: "%s',
    '%d projects' => '%d proyek',
    '%d project' => '%d proyek',
    'There is no project.' => 'Tidak ada proyek',
    'Sort' => 'Urutkan',
    'Project ID' => 'ID Proyek',
    'Project name' => 'Nama proyek',
    'Public' => 'Publik',
    'Personal' => 'Pribadi',
    '%d tasks' => '%d tugas',
    '%d task' => '%d tugas',
    'Task ID' => 'ID Tugas',
    'Assign automatically a color when due date is expired' => 'Tetapkan warna secara otomatis ketika tanggal jatuh tempo kadaluarsa',
    'Total score in this column across all swimlanes' => 'Skor total di kolom ini di semua swimlanes',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Peso Argentina',
    'COP - Colombian Peso' => 'COP - Peso Kolombia',
    '%d groups' => '%d grup',
    '%d group' => '%d grup',
    'Group ID' => 'ID Grup',
    'External ID' => 'ID External',
    '%d users' => '%d pengguna',
    '%d user' => '%d pengguna',
    'Hide subtasks' => 'Sembunyikan subtugas',
    'Show subtasks' => 'Tampilkan subtugas',
    'Authentication Parameters' => 'Parameter Otentikasi',
    'API Access' => 'Akses API',
    'No users found.' => 'Tidak ada pengguna yang ditemukan.',
    'User ID' => 'ID Pengguna',
    'Notifications are activated' => 'Notifikasi diaktifkan',
    'Notifications are disabled' => 'Notifikasi dinonaktifkan',
    'User disabled' => 'Pengguna dinonaktifkan',
    '%d notifications' => '%d notifikasi',
    '%d notification' => '%d notifikasi',
    'There is no external integration installed.' => 'Tidak ada integrasi eksternal yang terpasang.',
    'You are not allowed to update tasks assigned to someone else.' => 'Anda tidak diizinkan untuk memperbarui tugas yang diberikan kepada orang lain.',
    'You are not allowed to change the assignee.' => 'Anda tidak diizinkan untuk mengubah penerima.',
    'Task suppression is not permitted' => 'Penindasan tugas tidak diizinkan',
    'Changing assignee is not permitted' => 'Tidak diizinkan mengubah penerima',
    'Update only assigned tasks is permitted' => 'Perbarui hanya tugas yang diizinkan',
    'Only for tasks assigned to the current user' => 'Hanya untuk tugas yang diberikan kepada pengguna saat ini',
    'My projects' => 'Proyek saya',
    'You are not a member of any project.' => 'Anda bukan anggota proyek mana pun.',
    'My subtasks' => 'Subtugas saya',
    '%d subtasks' => '%d subtugas',
    '%d subtask' => '%d subtugas',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Hanya memindahkan tugas di antara kolom-kolom yang diizinkan untuk tugas yang diberikan kepada pengguna saat ini',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Krona Denmark',
    'Remove user from group' => 'Hapus pengguna dari grup',
    'Assign the task to its creator' => 'Tetapkan tugas untuk pembuatnya',
    'This task was sent by email to "%s" with subject "%s".' => 'Tugas ini dikirim melalui email ke "%s" dengan subjek "%s".',
    'Predefined Email Subjects' => 'Default Subjek Email',
    'Write one subject by line.' => 'Tulis satu subjek per baris.',
    'Create another link' => 'Buat tautan lain',
    'BRL - Brazilian Real' => 'BRL - Real Brasil',
    'Add a new Kanboard task' => 'Tambahkan tugas Kanboard baru',
    'Subtask not started' => 'Subtugas belum dimulai',
    'Subtask currently in progress' => 'Subtugas sedang dalam proses',
    'Subtask completed' => 'Subtugas selesai',
    'Subtask added successfully.' => 'Subtugas berhasil ditambahkan.',
    '%d subtasks added successfully.' => '%d subtugas berhasil ditambahkan.',
    'Enter one subtask by line.' => 'Masukkan satu subtugas per baris.',
    'Predefined Contents' => 'Default konten',
    'Predefined contents' => 'Default konten',
    'Predefined Task Description' => 'Default Deskripsi Tugas',
    'Do you really want to remove this template? "%s"' => 'Anda yakin ingin menghapus template ini? "%s"',
    'Add predefined task description' => 'Tambahkan deskripsi tugas default',
    'Predefined Task Descriptions' => 'Default deskripsi tugas',
    'Template created successfully.' => 'Template berhasil dibuat.',
    'Unable to create this template.' => 'Tidak dapat membuat template ini.',
    'Template updated successfully.' => 'Template berhasil diperbarui.',
    'Unable to update this template.' => 'Tidak dapat memperbarui template ini.',
    'Template removed successfully.' => 'Template berhasil dihapus.',
    'Unable to remove this template.' => 'Tidak dapat menghapus template ini.',
    'Template for the task description' => 'Template untuk deskripsi tugas',
    'The start date is greater than the end date' => 'Tanggal mulai lebih besar dari tanggal akhir',
    'Tags must be separated by a comma' => 'Tag harus dipisahkan dengan koma',
    'Only the task title is required' => 'Hanya judul tugas yang dibutuhkan',
    'Creator Username' => 'Nama Pengguna Pembuat',
    'Color Name' => 'Nama Warna',
    'Column Name' => 'Nama Kolom',
    'Swimlane Name' => 'Nama Swimlane',
    'Time Estimated' => 'Perkiraan Waktu',
    'Time Spent' => 'Waktu yang dihabiskan',
    'External Link' => 'Tautan Eksternal',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Fitur ini mengaktifkan umpan iCal, umpan RSS, dan tampilan papan publik.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Hentikan timer semua subtugas saat memindahkan tugas ke kolom lain',
    'Subtask Title' => 'Judul Subtugas',
    'Add a subtask and activate the timer when moving a task to another column' => 'Tambahkan subtugas dan aktifkan pengatur waktu saat memindahkan tugas ke kolom lain',
    'days' => 'hari',
    'minutes' => 'menit',
    'seconds' => 'detik',
    'Assign automatically a color when preset start date is reached' => 'Tetapkan warna secara otomatis ketika tanggal mulai preset tercapai',
    'Move the task to another column once a predefined start date is reached' => 'Pindahkan tugas ke kolom lain setelah tanggal mulai yang ditentukan tercapai',
    'This task is now linked to the task %s with the relation "%s"' => 'Tugas ini sekarang ditautkan ke tugas %s dengan relasi "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Tautan dengan relasi "%s" ke tugas %s telah dihapus',
    'Custom Filter:' => 'Kustomisasi Filter:',
    'Unable to find this group.' => 'Tidak dapat menemukan grup ini.',
    '%s moved the task #%d to the column "%s"' => '%s memindahkan tugas #%d ke kolom "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s memindahkan tugas #%d ke posisi %d di kolom "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s memindahkan tugas #%d ke swimlane "%s"',
    '%sh spent' => '%sh menghabiskan',
    '%sh estimated' => '%sh perkiraan',
    'Select All' => 'Pilih Semua',
    'Unselect All' => 'Batal Pilih Semua',
    'Apply action' => 'Terapkan tindakan',
    'Move selected tasks to another column or swimlane' => 'Pindahkan tugas yang dipilih ke kolom lain',
    'Edit tasks in bulk' => 'Edit tugas secara massal',
    'Choose the properties that you would like to change for the selected tasks.' => 'Pilih properti yang ingin Anda ubah untuk tugas yang dipilih.',
    'Configure this project' => 'Konfigurasi proyek ini',
    'Start now' => 'Mulai sekarang',
    '%s removed a file from the task #%d' => '%s menghapus file dari tugas #%d',
    'Attachment removed from task #%d: %s' => 'Lampiran dihapus dari tugas #%d: %s',
    'No color' => 'Tanpa warna',
    'Attachment removed "%s"' => 'Lampiran dihapus "%s"',
    '%s removed a file from the task %s' => '%s menghapus file dari tugas %s',
    'Move the task to another swimlane when assigned to a user' => 'Pindahkan tugas ke swimlane lain ketika ditugaskan ke pengguna',
    'Destination swimlane' => 'Swimlane tujuan',
    'Assign a category when the task is moved to a specific swimlane' => 'Tetapkan kategori ketika tugas dipindahkan ke swimlane tertentu',
    'Move the task to another swimlane when the category is changed' => 'Pindahkan tugas ke swimlane lain saat kategorinya diubah',
    'Reorder this column by priority (ASC)' => 'Susun ulang kolom ini berdasarkan prioritas (ASC)',
    'Reorder this column by priority (DESC)' => 'Susun ulang kolom ini berdasarkan prioritas (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Susun ulang kolom ini menurut penerima tugas dan prioritas (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Susun ulang kolom ini menurut penerima tugas dan prioritas (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Susun ulang kolom ini oleh penerima tugas (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Susun ulang kolom ini oleh penerima tugas (Z-A)',
    'Reorder this column by due date (ASC)' => 'Susun ulang kolom ini sebelum tanggal jatuh tempo (ASC)',
    'Reorder this column by due date (DESC)' => 'Susun ulang kolom ini berdasarkan tanggal jatuh tempo (DESC)',
    'Reorder this column by id (ASC)' => 'Susun ulang kolom ini berdasarkan id (ASC)',
    'Reorder this column by id (DESC)' => 'Susun ulang kolom ini berdasarkan id (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s memindahkan tugas #%d "%s" ke proyek "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Task #%d "%s" telah dipindahkan ke proyek "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Pindahkan tugas ke kolom lain ketika batas waktu kurang dari jumlah hari tertentu',
    'Automatically update the start date when the task is moved away from a specific column' => 'Secara otomatis memperbarui tanggal mulai ketika tugas dipindahkan dari kolom tertentu',
    'HTTP Client:' => 'HTTP Client:',
    'Assigned' => 'Ditugaskan',
    'Task limits apply to each swimlane individually' => 'Batas tugas berlaku untuk setiap swimlane secara individual',
    'Column task limits apply to each swimlane individually' => 'Batas tugas kolom berlaku untuk setiap swimlane secara individual',
    'Column task limits are applied to each swimlane individually' => 'Batas tugas kolom diterapkan ke setiap swimlane secara individual',
    'Column task limits are applied across swimlanes' => 'Batas tugas kolom diterapkan di seluruh swimlanes',
    'Task limit: ' => 'Batas tugas:',
    'Change to global tag' => 'Ubah ke tag global',
    'Do you really want to make the tag "%s" global?' => 'Anda yakin ingin menjadikan tag "%s" global?',
    'Enable global tags for this project' => 'Aktifkan tag global untuk proyek ini',
    'Group membership(s):' => 'Keanggotaan grup:',
    '%s is a member of the following group(s): %s' => '%s adalah anggota dari grup berikut: %s',
    '%d/%d group(s) shown' => '%d/%d grup ditampilkan',
    'Subtask creation or modification' => 'Pembuatan atau modifikasi subtugas',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Tetapkan tugas ke pengguna tertentu saat tugas dipindahkan ke swimlane tertentu',
    'Comment' => 'Komentar',
    'Collapse vertically' => 'Ciutkan secara vertikal',
    'Expand vertically' => 'Bentangkan secara vertikal',
    'MXN - Mexican Peso' => 'MXN - Peso Meksiko',
    'Estimated vs actual time per column' => 'Estimasi vs waktu aktual per kolom',
    'HUF - Hungarian Forint' => 'HUF - Forint Hongaria',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Anda harus memilih berkas untuk diunggah sebagai avatar Anda!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Berkas yang Anda unggah bukan gambar yang valid! (Hanya berkas *.gif, *.jpg, *.jpeg, dan *.png yang diizinkan!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Atur tenggat waktu secara otomatis ketika tugas dipindahkan dari kolom tertentu',
    'No other projects found.' => 'Tidak ada proyek lain yang ditemukan.',
    'Tasks copied successfully.' => 'Tugas berhasil disalin.',
    'Unable to copy tasks.' => 'Tidak dapat menyalin tugas.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Tema terang',
    'Dark theme' => 'Tema gelap',
    'Automatic theme - Sync with system' => 'Tema otomatis - Sinkronkan dengan sistem',
    'Application managers or more' => 'Pengelola aplikasi atau lebih',
    'Administrators' => 'Administrator',
    'Visibility:' => 'Visibilitas:',
    'Standard users' => 'Pengguna standar',
    'Visibility is required' => 'Visibilitas diperlukan',
    'The visibility should be an app role' => 'Visibilitas harus berupa peran aplikasi',
    'Reply' => 'Balas',
    '%s wrote: ' => '%s menulis: ',
    'Number of visible tasks in this column and swimlane' => 'Jumlah tugas yang terlihat di kolom dan lajur ini',
    'Number of tasks in this swimlane' => 'Jumlah tugas di lajur ini',
    'Unable to find another subtask in progress, you can close this window.' => 'Tidak dapat menemukan subtugas lain dalam proses, Anda dapat menutup jendela ini.',
    'This theme is invalid' => 'Tema ini tidak valid',
    'This role is invalid' => 'Peran ini tidak valid',
    'This timezone is invalid' => 'Zona waktu ini tidak valid',
    'This language is invalid' => 'Bahasa ini tidak valid',
    'This URL is invalid' => 'URL ini tidak valid',
    'Date format invalid' => 'Format tanggal tidak valid',
    'Time format invalid' => 'Format waktu tidak valid',
    'Invalid Mail transport' => 'Transportasi surel tidak valid',
    'Color invalid' => 'Warna tidak valid',
    'This value must be greater or equal to %d' => 'Nilai ini harus lebih besar dari atau sama dengan %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Tambahkan BOM di awal berkas (diperlukan untuk Microsoft Excel)',
    'Just add these tag(s)' => 'Cukup tambahkan tag ini',
    'Remove internal link(s)' => 'Hapus tautan internal',
    'Import tasks from another project' => 'Impor tugas dari proyek lain',
    'Select the project to copy tasks from' => 'Pilih proyek untuk menyalin tugas darinya',
    'The total maximum allowed attachments size is %sB.' => 'Ukuran total maksimum lampiran yang diizinkan adalah %sB.',
    'Add attachments' => 'Tambahkan lampiran',
    'Task #%d "%s" is overdue' => 'Tugas #%d "%s" sudah kadaluarsa',
    'Enable notifications by default for all new users' => 'Aktifkan notifikasi secara default untuk semua pengguna baru',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Tetapkan tugas kepada pembuatnya untuk kolom tertentu jika tidak ada penanggung jawab yang diatur secara manual',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Tetapkan tugas kepada pengguna yang masuk saat kolom berubah ke kolom yang ditentukan jika tidak ada pengguna yang ditetapkan',
];
